@@ -974,7 +974,7 @@ static int plugin_mark_loaded (char const *name)
 	return (status);
 }
 
-static void plugin_free_loaded ()
+static void plugin_free_loaded (void)
 {
 	void *key;
 	void *value;
@@ -1567,7 +1567,6 @@ int plugin_unregister_notification (const char *name)
 void plugin_init_all (void)
 {
 	char const *chain_name;
-	long write_threads_num;
 	llentry_t *le;
 	int status;
 
@@ -1851,10 +1850,10 @@ void plugin_shutdown_all (void)
 {
 	llentry_t *le;
 
-	stop_read_threads ();
-
 	destroy_all_callbacks (&list_init);
 
+	stop_read_threads ();
+
 	pthread_mutex_lock (&read_lock);
 	llist_destroy (read_list);
 	read_list = NULL;
@@ -1862,6 +1861,10 @@ void plugin_shutdown_all (void)
 
 	destroy_read_heap ();
 
+	/* blocks until all write threads have shut down. */
+	stop_write_threads ();
+
+	/* ask all plugins to write out the state they kept. */
 	plugin_flush (/* plugin = */ NULL,
 			/* timeout = */ 0,
 			/* identifier = */ NULL);
@@ -1891,8 +1894,6 @@ void plugin_shutdown_all (void)
 		plugin_set_ctx (old_ctx);
 	}
 
-	stop_write_threads ();
-
 	/* Write plugins which use the `user_data' pointer usually need the
 	 * same data available to the flush callback. If this is the case, set
 	 * the free_function to NULL when registering the flush callback and to
@@ -2272,7 +2273,7 @@ int plugin_dispatch_multivalue (value_list_t const *template, /* {{{ */
 		case DS_TYPE_GAUGE:
 			vl->values[0].gauge = va_arg (ap, gauge_t);
 			if (store_percentage)
-				vl->values[0].gauge *= 100.0 / sum;
+				vl->values[0].gauge *= sum ? (100.0 / sum) : NAN;
 			break;
 		case DS_TYPE_ABSOLUTE:
 			vl->values[0].absolute = va_arg (ap, absolute_t);
