@@ -498,7 +498,7 @@ static int network_dispatch_notification (notification_t *n) /* {{{ */
 } /* }}} int network_dispatch_notification */
 
 #if HAVE_LIBGCRYPT
-static void network_init_gcrypt (void) /* {{{ */
+static int network_init_gcrypt (void) /* {{{ */
 {
   gcry_error_t err;
 
@@ -506,7 +506,7 @@ static void network_init_gcrypt (void) /* {{{ */
    * Because you can't know in a library whether another library has
    * already initialized the library */
   if (gcry_control (GCRYCTL_ANY_INITIALIZATION_P))
-    return;
+    return (0);
 
  /* http://www.gnupg.org/documentation/manuals/gcrypt/Multi_002dThreading.html
   * To ensure thread-safety, it's important to set GCRYCTL_SET_THREAD_CBS
@@ -520,7 +520,7 @@ static void network_init_gcrypt (void) /* {{{ */
   if (err)
   {
     ERROR ("network plugin: gcry_control (GCRYCTL_SET_THREAD_CBS) failed: %s", gcry_strerror (err));
-    abort ();
+    return (-1);
   }
 # endif
 
@@ -529,12 +529,13 @@ static void network_init_gcrypt (void) /* {{{ */
   err = gcry_control (GCRYCTL_INIT_SECMEM, 32768);
   if (err)
   {
-    ERROR ("network plugin: gcry_control (GCRYCTL_SET_THREAD_CBS) failed: %s", gcry_strerror (err));
-    abort ();
+    ERROR ("network plugin: gcry_control (GCRYCTL_INIT_SECMEM) failed: %s", gcry_strerror (err));
+    return (-1);
   }
 
   gcry_control (GCRYCTL_INITIALIZATION_FINISHED);
-} /* }}} void network_init_gcrypt */
+  return (0);
+} /* }}} int network_init_gcrypt */
 
 static gcry_cipher_hd_t network_get_aes256_cypher (sockent_t *se, /* {{{ */
     const void *iv, size_t iv_size, const char *username)
@@ -2077,7 +2078,12 @@ static int sockent_init_crypto (sockent_t *se) /* {{{ */
 	{
 		if (se->data.client.security_level > SECURITY_LEVEL_NONE)
 		{
-			network_init_gcrypt ();
+			if (network_init_gcrypt () < 0)
+			{
+				ERROR ("network plugin: Cannot configure client socket with "
+						"security: Failed to initialize crypto library.");
+				return (-1);
+			}
 
 			if ((se->data.client.username == NULL)
 					|| (se->data.client.password == NULL))
@@ -2095,28 +2101,28 @@ static int sockent_init_crypto (sockent_t *se) /* {{{ */
 	}
 	else /* (se->type == SOCKENT_TYPE_SERVER) */
 	{
-		if (se->data.server.security_level > SECURITY_LEVEL_NONE)
+		if ((se->data.server.security_level > SECURITY_LEVEL_NONE)
+				&& (se->data.server.auth_file == NULL))
 		{
-			network_init_gcrypt ();
-
-			if (se->data.server.auth_file == NULL)
-			{
-				ERROR ("network plugin: Server socket with "
-						"security requested, but no "
-						"password file is configured.");
-				return (-1);
-			}
+			ERROR ("network plugin: Server socket with security requested, "
+					"but no \"AuthFile\" is configured.");
+			return (-1);
 		}
 		if (se->data.server.auth_file != NULL)
 		{
+			if (network_init_gcrypt () < 0)
+			{
+				ERROR ("network plugin: Cannot configure server socket with security: "
+						"Failed to initialize crypto library.");
+				return (-1);
+			}
+
 			se->data.server.userdb = fbh_create (se->data.server.auth_file);
 			if (se->data.server.userdb == NULL)
 			{
-				ERROR ("network plugin: Reading password file "
-						"`%s' failed.",
+				ERROR ("network plugin: Reading password file \"%s\" failed.",
 						se->data.server.auth_file);
-				if (se->data.server.security_level > SECURITY_LEVEL_NONE)
-					return (-1);
+				return (-1);
 			}
 		}
 	}
@@ -2909,6 +2915,11 @@ static int network_write (const data_set_t *ds, const value_list_t *vl,
 {
 	int status;
 
+	/* listen_loop is set to non-zero in the shutdown callback, which is
+	 * guaranteed to be called *after* all the write threads have been shut
+	 * down. */
+	assert (listen_loop == 0);
+
 	if (!check_send_okay (vl))
 	{
 #if COLLECT_DEBUG
@@ -3547,10 +3558,6 @@ static int network_init (void)
 		return (0);
 	have_init = 1;
 
-#if HAVE_LIBGCRYPT
-	network_init_gcrypt ();
-#endif
-
 	if (network_config_stats != 0)
 		plugin_register_read ("network", network_stats_read);
 
