@@ -26,14 +26,8 @@
  *   Florian octo Forster <octo at collectd.org>
  */
 
-#include <sys/socket.h>
-#include <arpa/inet.h>
-#include <errno.h>
-#include <netdb.h>
-#include <inttypes.h>
-#include <pthread.h>
-
 #include "collectd.h"
+
 #include "plugin.h"
 #include "common.h"
 #include "configfile.h"
@@ -41,10 +35,14 @@
 #include "riemann.pb-c.h"
 #include "write_riemann_threshold.h"
 
+#include <sys/socket.h>
+#include <arpa/inet.h>
+#include <netdb.h>
+
 #define RIEMANN_HOST		"localhost"
 #define RIEMANN_PORT		"5555"
-#define RIEMANN_TTL_FACTOR      2.0
-#define RIEMANN_BATCH_MAX      8192
+#define RIEMANN_TTL_FACTOR	2.0
+#define RIEMANN_BATCH_MAX	8192
 
 struct riemann_host {
 	char			*name;
